aboutsummaryrefslogtreecommitdiffstats
path: root/core/governance.go
diff options
context:
space:
mode:
authorWei-Ning Huang <w@dexon.org>2018-08-10 15:12:56 +0800
committerJimmy Hu <jimmy.hu@dexon.org>2018-08-10 15:12:56 +0800
commit09a0ab086cdafcb27b74e6346efdc8e96ca8145d (patch)
treec14bda316a48c94e5300b5799f152a82f0594558 /core/governance.go
parent03917cdfa1f762849541e1bed31394340ed1f957 (diff)
downloaddexon-consensus-09a0ab086cdafcb27b74e6346efdc8e96ca8145d.tar
dexon-consensus-09a0ab086cdafcb27b74e6346efdc8e96ca8145d.tar.gz
dexon-consensus-09a0ab086cdafcb27b74e6346efdc8e96ca8145d.tar.bz2
dexon-consensus-09a0ab086cdafcb27b74e6346efdc8e96ca8145d.tar.lz
dexon-consensus-09a0ab086cdafcb27b74e6346efdc8e96ca8145d.tar.xz
dexon-consensus-09a0ab086cdafcb27b74e6346efdc8e96ca8145d.tar.zst
dexon-consensus-09a0ab086cdafcb27b74e6346efdc8e96ca8145d.zip
core: update governance interface and move K into config (#40)
Diffstat (limited to 'core/governance.go')
-rw-r--r--core/governance.go10
1 files changed, 8 insertions, 2 deletions
diff --git a/core/governance.go b/core/governance.go
index a7069a5..d94fad0 100644
--- a/core/governance.go
+++ b/core/governance.go
@@ -30,9 +30,15 @@ type Governance interface {
// Get the current validator set and it's corresponding stake.
GetValidatorSet() map[types.ValidatorID]decimal.Decimal
+ // Get K
+ GetTotalOrderingK() int
+
+ // Get PhiRatio
+ GetPhiRatio() float32
+
// Get block proposing interval (in milliseconds).
GetBlockProposingInterval() int
- // Get membership events after a certain epoch.
- GetMembershipEvents(epoch int) []types.MembershipEvent
+ // Get configuration change events after a certain epoch.
+ GetConfigurationChangeEvent(epoch int) []types.ConfigurationChangeEvent
}